@@ -3,14 +3,19 @@ import os
 from io import StringIO
 
 import paramiko
+from dagster import (
+    BoolSource,
+    Field,
+    IntSource,
+    StringSource,
+    _check as check,
+    resource,
+)
+from dagster._utils import mkdir_p
+from dagster._utils.merger import merge_dicts
 from paramiko.config import SSH_PORT
 from sshtunnel import SSHTunnelForwarder
 
-from dagster import BoolSource, Field, IntSource, StringSource
-from dagster import _check as check
-from dagster import resource
-from dagster._utils import merge_dicts, mkdir_p
-
 
 def key_from_str(key_str):
     """Creates a paramiko SSH key from a string."""
@@ -26,6 +31,7 @@ def key_from_str(key_str):
 class SSHResource:
     """
     Resource for ssh remote execution using Paramiko.
+
     ref: https://github.com/paramiko/paramiko
     """
 
@@ -67,7 +73,8 @@ class SSHResource:
         if not self.username:
             logger.debug(
                 "username to ssh to host: %s is not specified. Using system's default provided by"
-                " getpass.getuser()" % self.remote_host
+                " getpass.getuser()"
+                % self.remote_host
             )
             self.username = getpass.getuser()
 
